==> goods-center-api-1.6.7.6-20161021.030822-2-sources.jar: cn/com/duiba/goods/center/api/remoteservice/front/RemotePCGGoodsInfoService.java <==
/**
 * Project Name:goods-center-api
 * File Name:RemotePCGGoodsInfoService.java
 * Package Name:cn.com.duiba.goods.center.api.remoteservice.front
 * Date:2016年6月29日下午8:53:46
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.api.remoteservice.front;

import cn.com.duiba.goods.center.api.remoteservice.dto.*;
import cn.com.duiba.goods.center.api.remoteservice.dto.pcg.PcgDetailDto;
import cn.com.duiba.goods.center.api.remoteservice.tool.Page;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * ClassName:RemotePCGGoodsInfoService <br/>
 * Function: 平台券商品信息查询. <br/>
 * Date:     2016年6月29日 下午8:53:46 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface RemotePCGGoodsInfoService {
    /**
     * 查询商品(不包含已删除的商品)
     *
     * @author xuhengfei
     * @param pcgId 商品id
     * @return 商品信息
     * @since JDK 1.6
     */
    public PCGDto find(long pcgId);
    
    /**
     * 提供给详情页的查询接口
     * @author xuhengfei
     * @param pcgId
     * @since JDK 1.6
     */
    public DubboResult<PcgDetailDto> findForDetail(long pcgId,long appId);
    /**
     * 查询商品(包含已经删除的商品)
     *
     * @author xuhengfei
     * @param pcgId 商品id
     * @return 商品信息
     * @since JDK 1.6
     */
    public PCGDto findIncludeDeleted(long pcgId);
    /**
     * 
     * findCategoryAll:查询所有的分类 <br/>
     *
     * @author zhengjy
     * @return 结果集
     * @since JDK 1.6
     */
    DubboResult<List<PCGCategoryDto>> findCategoryAll();
    /**
     * 
     * findSellerAll:查询所有品牌 <br/>
     *
     * @author zhengjy
     * @return 结果集
     *14 @since JDK 1.6
     */
    DubboResult<List<PCGSellerDto>> findSellerAll();
    
   
    /**
     * 查询app下屏蔽分类，品牌或商品 <br/>
     * @param appId 
     * @param type  type  1:优惠券 2:分类 3:品牌
     * @return 结果集
     */
    DubboResult<List<Long>>  findPCGFilterTargetIds(Long appId,Integer type);
    
    /**
     * 查询分类下商品列表<br/>
     * @param appId
     * @param consumerId 用户id
     * @param consumerCredits 用户积分
     * @param pageIndex 页码
     * @param pageSize 分页大小
     * @return 分页结果集
     */
    DubboResult<Page<PCGCategorySellerGoodsDto>> findCategoryGoods(long appId,long categoryId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize);
    
    /**
     * 查询品牌下商品列表<br/>
     * @param appId
     * @param consumerId 用户id
     * @param consumerCredits 用户积分
     * @param pageIndex 页码
     * @param pageSize 分页大小
     * @return 分页结果集
     */
    DubboResult<Page<PCGCategorySellerGoodsDto>> findSellerGoods(long appId,long sellerId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize);
    
    /**
     * 查询平台券详细信息 （包括 兑换状态）<br/>
     * @param appId
     * @param gid 平台券id
     * @param consumerId 用户id
     * @param consumerCredits 用户积分
     * @author guoey
     * @return 商品信息
     */
    DubboResult<PCGCategorySellerGoodsDto> findSellerGoodsInfo(long appId,long gid,Long consumerId,Long consumerCredits);

    /**
     * 手机端,楼层定制,获取平台券 pcgIds
     * @param appId
     * @param size
     * @return
     */
    @Deprecated
    DubboResult<List<Long>> findPcgIds4Floor(Long appId, Integer size);

    /**
     * 手机端,楼层,获取平台券 根据 pcgIds
     * @param pcgIds
     * @return
     */
    @Deprecated
    DubboResult<List<PCGFloorDto>> findPcg4Floor(List<Long> pcgIds, Long appId, Long consumerId, Long appRate, Long consumerCredits);

    /**
     * 手机端,楼层定制,获取平台券
     * @param appId
     * @param size
     * @return
     */
    DubboResult<List<PCGFloorDto>> findPcg4Floor(Long appId, Integer size);
}

==> goods-center-api-2.2.1-20171016.033311-1-sources.jar: cn/com/duiba/goods/center/api/remoteservice/front/RemotePCGGoodsInfoService.java <==
/**
 * Project Name:goods-center-api
 * File Name:RemotePCGGoodsInfoService.java
 * Package Name:cn.com.duiba.goods.center.api.remoteservice.front
 * Date:2016年6月29日下午8:53:46
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.goods.center.api.remoteservice.front;

import java.util.List;

import cn.com.duiba.goods.center.api.remoteservice.dto.PCGCategoryDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGCategorySellerGoodsDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGFloorDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.PCGSellerDto;
import cn.com.duiba.goods.center.api.remoteservice.dto.pcg.PcgDetailDto;
import cn.com.duiba.goods.center.api.remoteservice.tool.Page;
import cn.com.duiba.wolf.dubbo.DubboResult;

/**
 * ClassName:RemotePCGGoodsInfoService <br/>
 * Function: 平台券商品信息查询. <br/>
 * Date:     2016年6月29日 下午8:53:46 <br/>
 * @author   xuhengfei
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public interface RemotePCGGoodsInfoService {
    /**
     * 查询商品(不包含已删除的商品)
     *
     * @author xuhengfei
     * @param pcgId 商品id
     * @return 商品信息
     * @since JDK 1.6
     */
    public PCGDto find(long pcgId);
    
    /**
     * 提供给详情页的查询接口
     * @param pcgId
     * @param appId
     * @return
     */
    public DubboResult<PcgDetailDto> findForDetail(long pcgId,long appId);
    /**
     * 查询商品(包含已经删除的商品)
     *
     * @author xuhengfei
     * @param pcgId 商品id
     * @return 商品信息
     * @since JDK 1.6
     */
    public PCGDto findIncludeDeleted(long pcgId);
    /**
     * 
     * findCategoryAll:查询所有的分类 <br/>
     *
     * @author zhengjy
     * @return 结果集
     * @since JDK 1.6
     */
    DubboResult<List<PCGCategoryDto>> findCategoryAll();
    /**
     * 
     * findSellerAll:查询所有品牌 <br/>
     *
     * @author zhengjy
     * @return 结果集
     * @since JDK 1.6
     */
    DubboResult<List<PCGSellerDto>> findSellerAll();
    
   
    /**
     * 查询app下屏蔽分类，品牌或商品 <br/>
     * @param appId 
     * @param type  type  1:优惠券 2:分类 3:品牌
     * @return 结果集
     */
    DubboResult<List<Long>>  findPCGFilterTargetIds(Long appId,Integer type);
    
    /**
     * 查询分类下商品列表<br/>
     * @param appId
     * @param categoryId
     * @param consumerId 用户id
     * @param consumerCredits 用户积分
     * @param pageIndex 页码
     * @param pageSize 分页大小
     * @return 分页结果集
     */
    DubboResult<Page<PCGCategorySellerGoodsDto>> findCategoryGoods(long appId,long categoryId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize);
    
    /**
     * 查询品牌下商品列表<br/>
     * @param appId
     * @param sellerId
     * @param consumerId 用户id
     * @param consumerCredits 用户积分
     * @param pageIndex 页码
     * @param pageSize 分页大小
     * @return 分页结果集
     */
    DubboResult<Page<PCGCategorySellerGoodsDto>> findSellerGoods(long appId,long sellerId,Long consumerId,Long consumerCredits, Integer pageIndex, Integer pageSize);
    
    /**
     * 查询平台券详细信息 （包括 兑换状态）<br/>
     * @param appId
     * @param gid 平台券id
     * @param consumerId 用户id
     * @param consumerCredits 用户积分
     * @author guoey
     * @return 商品信息
     */
    DubboResult<PCGCategorySellerGoodsDto> findSellerGoodsInfo(long appId,long gid,Long consumerId,Long consumerCredits);

    /**
     * @Deprecated
     * 废弃原因,因为在逻辑中存在平级调用,从而将业务上浮到web端
     * @param appId
     * @param size
     * @return
     */
    DubboResult<List<PCGFloorDto>> findPcg4Floor(Long appId, Integer size);

    /**
     * 获取所有可展示的平台券
     * 获取逻辑,取每个分类的前两个,但是为过滤做预留,每个分类下取4个
     * 如果App下有3个优惠券分类项,则加载 3*4 = 12
     * @param appId
     * @param appTags
     * @return
     */
    DubboResult<List<PCGFloorDto>> findAllPcg4Floor(Long appId,String appTags);
}
